==> guessnet_0.28-1.tar.gz: guessnet-0.28-1/src/Parser.cc <==
/*
 * Common facilities used by scan data parsers
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Parser.h"
#include "stringf.h"

using namespace std;
using namespace stringf;

string ParserException::desc() const throw ()
{
	if (_file.size() > 0)
		if (_line != -1)
			return _file + ":" + fmt(_line) + ": " + _context;
		else
			return _file + ":" + _context;
	else
		if (_line != -1)
			return fmt(_line) + ": " + _context;
		else
			return _context;
}

string DefaultScan::signature() const throw ()
{
	return "default";
}

string LinkBeatScan::signature() const throw ()
{
	return "linkbeat";
}

string PeerScan::signature() const throw ()
{
	return "peer " + fmt(ip()) + " " + fmt(mac());
}

string ScriptScan::signature() const throw ()
{
	return "script " + cmdline();
}

// vim:set ts=4 sw=4:

==> guessnet_0.35.orig.tar.gz: guessnet-0.35/src/Parser.cc <==
/*
 * Common facilities used by test data parsers
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Parser.h"
#include "stringf.h"

using namespace std;
using namespace stringf;

string ParserException::desc() const throw ()
{
	if (_file.size() > 0)
		if (_line != -1)
			return _file + ":" + fmt(_line) + ": " + _context;
		else
			return _file + ":" + _context;
	else
		if (_line != -1)
			return fmt(_line) + ": " + _context;
		else
			return _context;
}

string DefaultScan::signature() const throw ()
{
	return "default";
}

string PeerScan::signature() const throw ()
{
	return "peer " + fmt(ip()) + " " + fmt(mac());
}

string LinkBeatScan::signature() const throw ()
{
	return "linkbeat";
}

string ScriptScan::signature() const throw ()
{
	return "command '" + cmdline() + "'";
}

string DHCPScan::signature() const throw ()
{
	return "dhcp";// + fmt(ip()) + " " + fmt(mac());
}

// vim:set ts=4 sw=4:
